@@ -4,6 +4,8 @@
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
+{-# LANGUAGE CPP #-}
+
 module Codec.Encryption.OpenPGP.CFB (
    decrypt
  , decryptNoNonce
@@ -12,18 +14,12 @@ module Codec.Encryption.OpenPGP.CFB (
 ) where
 
 import Codec.Encryption.OpenPGP.BlockCipher (withSymmetricCipher)
-import Codec.Encryption.OpenPGP.Internal
-import Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
-import Codec.Encryption.OpenPGP.Internal.Cryptonite
 import Codec.Encryption.OpenPGP.Internal.HOBlockCipher
 import Codec.Encryption.OpenPGP.Types
+#if !MIN_VERSION_base(4,8,0)
 import Control.Applicative ((<$>), (<*>))
-import Control.Error.Util (note)
-import qualified Crypto.Cipher.AES as CCA
-import qualified Crypto.Cipher.Blowfish as CCB
-import qualified Crypto.Cipher.TripleDES as CC3
-import qualified Crypto.Nettle.Ciphers as CNC
-import Data.ByteArray (ByteArray)
+#endif
+import Control.Monad (liftM)
 import qualified Data.ByteString as B
 
 decryptOpenPGPCfb :: SymmetricAlgorithm -> B.ByteString -> B.ByteString -> Either String B.ByteString
@@ -36,12 +32,12 @@ decryptOpenPGPCfb sa ciphertext keydata = withSymmetricCipher sa keydata $ \bc -
         decrypt1 :: HOBlockCipher cipher => B.ByteString -> cipher -> Either String B.ByteString
         decrypt1 ct cipher = paddedCfbDecrypt cipher (B.replicate (blockSize cipher) 0) (B.take (blockSize cipher + 2) ct)
         decrypt2 :: HOBlockCipher cipher => B.ByteString -> cipher -> Either String B.ByteString
-        decrypt2 ct cipher = let i = B.take (blockSize cipher) (B.drop 2 ct) in (paddedCfbDecrypt cipher i (B.drop (blockSize cipher + 2) ct))
+        decrypt2 ct cipher = let i = B.take (blockSize cipher) (B.drop 2 ct) in paddedCfbDecrypt cipher i (B.drop (blockSize cipher + 2) ct)
 
 decrypt :: SymmetricAlgorithm -> B.ByteString -> B.ByteString -> Either String B.ByteString
 decrypt Plaintext ciphertext _ = return ciphertext
 decrypt sa ciphertext keydata = withSymmetricCipher sa keydata $ \bc -> do
-    (nonce, cleartext) <- decrypt' ciphertext bc >>= return . (B.splitAt (blockSize bc + 2))
+    (nonce, cleartext) <- liftM (B.splitAt (blockSize bc + 2)) (decrypt' ciphertext bc)
     if nonceCheck bc nonce then return cleartext else Left "Session key quickcheck failed"
     where
         decrypt' :: HOBlockCipher cipher => B.ByteString -> cipher -> Either String B.ByteString
@@ -49,8 +45,7 @@ decrypt sa ciphertext keydata = withSymmetricCipher sa keydata $ \bc -> do
 
 decryptNoNonce :: SymmetricAlgorithm -> IV -> B.ByteString -> B.ByteString -> Either String B.ByteString
 decryptNoNonce Plaintext _ ciphertext _ = return ciphertext
-decryptNoNonce sa iv ciphertext keydata = do
-    withSymmetricCipher sa keydata (decrypt' ciphertext)
+decryptNoNonce sa iv ciphertext keydata = withSymmetricCipher sa keydata (decrypt' ciphertext)
     where
         decrypt' :: HOBlockCipher cipher => B.ByteString -> cipher -> Either String B.ByteString
         decrypt' ct cipher = paddedCfbDecrypt cipher (unIV iv) ct
@@ -59,9 +54,8 @@ nonceCheck :: HOBlockCipher cipher => cipher -> B.ByteString -> Bool
 nonceCheck bc = (==) <$> B.take 2 . B.drop (blockSize bc - 2) <*> B.drop (blockSize bc)
 
 encryptNoNonce :: SymmetricAlgorithm -> S2K -> IV -> B.ByteString -> B.ByteString -> Either String B.ByteString
-encryptNoNonce Plaintext _ _ payload keydata = return payload
-encryptNoNonce sa s2k iv payload keydata = do
-    withSymmetricCipher sa keydata (encrypt' payload)
+encryptNoNonce Plaintext _ _ payload _ = return payload
+encryptNoNonce sa s2k iv payload keydata = withSymmetricCipher sa keydata (encrypt' payload)
     where
         encrypt' :: HOBlockCipher cipher => B.ByteString -> cipher -> Either String B.ByteString
         encrypt' ct cipher = paddedCfbEncrypt cipher (unIV iv) ct
