@@ -38,6 +38,7 @@ import Data.Maybe (fromJust)
 import Data.Word (Word8, Word16)
 
 import Codec.Encryption.OpenPGP.Types
+import Codec.Encryption.OpenPGP.Ontology (isIssuerSSP, isSigCreationTime)
 
 countBits :: ByteString -> Word16
 countBits bs
@@ -59,10 +60,7 @@ emptyPSC :: PktStreamContext
 emptyPSC = PktStreamContext (OtherPacketPkt 0 "lastLD placeholder") (OtherPacketPkt 0 "lastUIDorUAt placeholder") (OtherPacketPkt 0 "lastSig placeholder") (OtherPacketPkt 0 "lastPrimaryKey placeholder") (OtherPacketPkt 0 "lastSubkey placeholder")
 
 issuer :: Pkt -> Maybe EightOctetKeyId
-issuer (SignaturePkt (SigV4 _ _ _ _ usubs _ _)) = fmap (\(SigSubPacket _ (Issuer i)) -> i) (find isIssuer usubs)
-    where
-        isIssuer (SigSubPacket _ (Issuer _)) = True
-        isIssuer _ = False
+issuer (SignaturePkt (SigV4 _ _ _ _ usubs _ _)) = fmap (\(SigSubPacket _ (Issuer i)) -> i) (find isIssuerSSP usubs)
 issuer _ = Nothing
 
 pubkeyToMPIs :: PKey -> [MPI]
@@ -100,9 +98,6 @@ sigHA _ = Nothing -- this includes v2 sigs, which don't seem to be specified in
 sigCT :: SignaturePayload -> Maybe ThirtyTwoBitTimeStamp
 sigCT (SigV3 _ ct _ _ _ _ _) = Just ct
 sigCT (SigV4 _ _ _ hsubs _ _ _) = fmap (\(SigSubPacket _ (SigCreationTime i)) -> i) (find isSigCreationTime hsubs)
-    where
-        isSigCreationTime (SigSubPacket _ (SigCreationTime _)) = True
-        isSigCreationTime _ = False
 sigCT _ = Nothing
 
 truncatingVerify :: (ByteArrayAccess msg, CHI.HashAlgorithm hash) => hash -> DSA.PublicKey -> DSA.Signature -> msg -> Bool
