@@ -6,8 +6,11 @@
 {-# LANGUAGE CPP #-}
 
 module Codec.Encryption.OpenPGP.Serialize (
+  -- * Serialization functions
    putSKAddendum
  , getSecretKey
+  -- * Utilities
+ , parsePkts
 ) where
 
 #if !MIN_VERSION_base(4,8,0)
@@ -783,7 +786,7 @@ getPubkey ForbiddenElgamal = do MPI p <- get
 getPubkey _ = UnknownPKey <$> getRemainingLazyByteString
 
 putPubkey :: PKey -> Put
-putPubkey (UnknownPKey bs) = put bs
+putPubkey (UnknownPKey bs) = putLazyByteString bs
 putPubkey p = mapM_ put (pubkeyToMPIs p)
 
 getSecretKey :: PKPayload -> Get SKey
@@ -1235,3 +1238,10 @@ putTK key = do
         putUid' (u, sps) = put (UserId u) >> mapM_ (put . Signature) sps
         putUat' (us, sps) = put (UserAttribute us) >> mapM_ (put . Signature) sps
         putSub' (p, sps) = put p >> mapM_ (put . Signature) sps
+
+-- | Parse the packets from a ByteString, with no error reporting
+parsePkts :: ByteString -> [Pkt]
+parsePkts lbs =
+    case runGetOrFail (some getPkt) lbs of
+        Left (_, _, e) -> []
+        Right (_, _, p) -> p
