@@ -37,6 +37,8 @@ import Data.Binary.Put (runPut)
 
 import Codec.Encryption.OpenPGP.Fingerprint (eightOctetKeyID, fingerprint)
 import Codec.Encryption.OpenPGP.Internal (PktStreamContext(..), issuer, emptyPSC, truncatingVerify)
+import Codec.Encryption.OpenPGP.Ontology (isRevokerP, isRevocationKeySSP, isSubkeyBindingSig, isSubkeyRevocation)
+
 import Codec.Encryption.OpenPGP.SerializeForSigs (putPartialSigforSigning, putSigTrailer, payloadForSig)
 import Codec.Encryption.OpenPGP.Types
 import Data.Conduit.OpenPGP.Keyring.Instances ()
@@ -83,16 +85,6 @@ verifyTKWith vsf mt key = do
                                      (s@(SigV4 SignatureDirectlyOnAKey _ _ _ _ _ _), _) -> [Right s]
                                      (s@(SigV4 KeyRevocationSig pka _ _ _ _ _), v) -> if (v^.verificationSigner == key ^. tkKey._1) || any (\(p,f) -> p == pka && f == fingerprint (v^.verificationSigner)) vokers then [Left "Key revoked"] else [Right s]
                                      _ -> []
-        isSubkeyRevocation (SigV4 SubkeyRevocationSig _ _ _ _ _ _) = True
-        isSubkeyRevocation _ = False
-        isSubkeyBindingSig (SigV4 SubkeyBindingSig _ _ _ _ _ _) = True
-        isSubkeyBindingSig _ = False
-        isRevokerP (SigV4 SignatureDirectlyOnAKey _ _ h u _ _) = any isRevocationKeySSP h && any isIssuerSSP u
-        isRevokerP _ = False
-        isRevocationKeySSP (SigSubPacket _ (RevocationKey {})) = True
-        isRevocationKeySSP _ = False
-        isIssuerSSP (SigSubPacket _ (Issuer _)) = True
-        isIssuerSSP _ = False
         vUid :: (Text, SignaturePayload) -> Either String Verification
         vUid (uid, sp) = vsf (SignaturePkt sp) emptyPSC { lastPrimaryKey = PublicKeyPkt (key ^. tkKey._1), lastUIDorUAt = UserIdPkt uid } mt
         vUAt :: ([UserAttrSubPacket], SignaturePayload) -> Either String Verification
