@@ -13,8 +13,9 @@ import Data.Conduit
 import qualified Data.Conduit.List as CL
 import Data.IxSet.Typed (empty, insert)
 
-import Codec.Encryption.OpenPGP.KeyringParser (finalizeParsing, parseAChunk, parseTK)
+import Codec.Encryption.OpenPGP.KeyringParser (finalizeParsing, parseAChunk, anyTK)
 import Codec.Encryption.OpenPGP.Types
+import Codec.Encryption.OpenPGP.Ontology (isTrustPkt)
 import Data.Conduit.OpenPGP.Keyring.Instances ()
 
 data Phase = MainKey | Revs | Uids | UAts | Subs | SkippingBroken
@@ -39,10 +40,9 @@ fakecmAccum finalizer f =
             loop accum'
 
 conduitToTKs' :: Monad m => Bool -> Conduit Pkt m TK
-conduitToTKs' intolerant = CL.filter notTrustPacket =$= CL.map (:[]) =$= fakecmAccum finalizeParsing (parseAChunk (parseTK intolerant)) ([], Just (Nothing, parseTK intolerant)) =$= CL.catMaybes
+conduitToTKs' intolerant = CL.filter notTrustPacket =$= CL.map (:[]) =$= fakecmAccum finalizeParsing (parseAChunk (anyTK intolerant)) ([], Just (Nothing, anyTK intolerant)) =$= CL.catMaybes
     where
-        notTrustPacket (TrustPkt _) = False
-        notTrustPacket _ = True
+        notTrustPacket = not . isTrustPkt
 
 sinkKeyringMap :: Monad m => Sink TK m Keyring
 sinkKeyringMap = CL.fold (flip insert) empty
