@@ -16,9 +16,10 @@ import Codec.Encryption.OpenPGP.Arbitrary ()
 import Codec.Encryption.OpenPGP.Compression (decompressPkt, compressPkts)
 import Codec.Encryption.OpenPGP.Expirations (isTKTimeValid)
 import Codec.Encryption.OpenPGP.Fingerprint (eightOctetKeyID, fingerprint)
+import Codec.Encryption.OpenPGP.KeyringParser (parseTKs)
 import Codec.Encryption.OpenPGP.KeySelection (parseFingerprint)
 import Codec.Encryption.OpenPGP.SecretKey (decryptPrivateKey, encryptPrivateKey)
-import Codec.Encryption.OpenPGP.Serialize ()
+import Codec.Encryption.OpenPGP.Serialize (parsePkts)
 import Codec.Encryption.OpenPGP.Signatures (verifyTKWith, verifySigWith, verifyAgainstKeys)
 import Codec.Encryption.OpenPGP.Types
 import Control.Error.Util (isRight)
@@ -162,6 +163,20 @@ testSecretKeyEncryption keyfile passfile = do
       newtruck = toPkt (SecretKey pkp newska):tail kr
   assertEqual "encrypted private key matches golden file" gkr newtruck
 
+testParsePktsUtil :: FilePath -> Assertion
+testParsePktsUtil fn = do
+    let fpath = "tests/data/" ++ fn
+    cp <- runResourceT $ CB.sourceFile fpath DC.$= conduitGet get DC.$$ CL.consume
+    pp <- BL.readFile fpath >>= return . parsePkts
+    assertEqual "parsePkts utility function gives same results as conduit pipeline" cp pp
+
+testParseTKsUtil :: FilePath -> Assertion
+testParseTKsUtil fn = do
+    let fpath = "tests/data/" ++ fn
+    lbs <- BL.readFile fpath
+    cp <- runResourceT $ CB.sourceLbs lbs DC.$= conduitGet get DC.$= conduitToTKs DC.$$ CL.consume
+    let pt = parseTKs True . parsePkts $ lbs
+    assertEqual "parsePkts utility function gives same results as conduit pipeline" cp pt
 
 tests :: TestTree
 tests = testGroup "Tests" [properties, unitTests]
@@ -259,6 +274,7 @@ unitTests = testGroup "Unit Tests" [
    , testCase "v3-genericcert.sig" (testSerialization "v3-genericcert.sig")
    , testCase "sigs-with-regexes" (testSerialization "sigs-with-regexes")
    , testCase "gnu-dummy-s2k-101-secret-key.gpg" (testSerialization "gnu-dummy-s2k-101-secret-key.gpg")
+   , testCase "anibal-ed25519.gpg" (testSerialization "anibal-ed25519.gpg")
    ],
   testGroup "KeyID/fingerprint group" [
      testCase "v3 key" (testKeyIDandFingerprint "v3.key" "C7261095/CBD9 F412 6807 E405 CC2D  2712 1DF5 E86E")
@@ -347,6 +363,10 @@ unitTests = testGroup "Unit Tests" [
    ],
   testGroup "Encrypting secret keys" [
      testCase "SUSSHA1 AES256 IteratedSalted SHA512 RSA" (testSecretKeyEncryption "unencrypted.seckey" "pki-password.txt")
+   ],
+  testGroup "Utility function group" [
+     testCase "pubring as packets" (testParsePktsUtil "pubring.gpg")
+   , testCase "pubring as TKs" (testParseTKsUtil "pubring.gpg")
    ]
  ]
 
